"""A simple python library for getting caller ID name information."""


from .errors import *
from .opencnam import *


__author__ = 'Randall Degges'
__copyright__ = 'Telephony Research Services, LLC'
__credits__ = ('Randall Degges', )

__license__ = 'UNLICENSE'
__version = '0.2'
__maintainer__ = 'Randall Degges'
__email__ = 'rdegges@gmail.com'
__status__ = 'Development'
